<?php

declare(strict_types=1);

/*
 * Copyright (c) 2023 François Kooman <fkooman@tuxed.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

require_once __DIR__ . '/autoload.php';

use fkooman\Radius\ErrorLogger;
use fkooman\Radius\Exception\AuthException;
use fkooman\Radius\RadiusClient;

function myGetEnv(string $envVar, string $defaultValue): string
{
    $envVal = getenv($envVar);
    if (!is_string($envVal)) {
        return $defaultValue;
    }

    return $envVal;
}

$radiusAuth = new RadiusClient(myGetEnv('NAS_ID', 'my-nas-id'), new ErrorLogger(ErrorLogger::DEBUG));
$radiusAuth->addServer(
    myGetEnv('SERVER_ADDRESS', '127.0.0.1'),
    myGetEnv('SHARED_SECRET', 's3cr3t'),
    (int) myGetEnv('SERVER_PORT', '1812')
);

if ($argc < 3) {
    echo 'SYNTAX: ' . $argv[0] . ' User-Name User-Password' . PHP_EOL;
    exit(1);
}

try {
    $accessResponse = $radiusAuth->accessRequest($argv[1], $argv[2]);
    echo '***OK***' . PHP_EOL;
    echo $accessResponse;
} catch (AuthException $e) {
    $accessResponse = $e->accessResponse();
    echo '***FAIL***' . PHP_EOL;
    echo $accessResponse;

    exit(1);
} catch (Exception $e) {
    echo 'ERROR (' . get_class($e) . '): ' . $e->getMessage() . PHP_EOL;
    exit(1);
}
